==> cutemaze_1.2.0.orig.tar.gz: cutemaze-1.2.0/translations/cutemaze_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Невозможно загрузить предыдущую игру. Будет создана новая игра.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 прошло</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 шагов сделано</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 из %2 целей осталось</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Успех</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Пауза</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Опция</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Выберите язык приложения:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Системный язык&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Пожалуйста, перезапустите программу для того, чтобы изменения вступили в силу.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Новая игра</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Охота и убийство</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Краскал</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Прим</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Рекурсивный обход</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Стек</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Стек 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Стек 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Стек 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Стек 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Алгоритм:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Целей:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Размер:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Охота и убийство</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Краскал</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Прим</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Рекурсивный обход</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Стек</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation> Стек 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Стек 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Стек 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Стек 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Очки CuteMaze</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Очки</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Шагов</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Алгоритм</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Поздравляем!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Вы попали в десятку лучших.
Пожалуйста. введите свое имя:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Игра</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Показывать, где вы уже были</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Показывать количество шагов</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Показывать прошедшее время</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Гладкое движение</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Управление</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Вверх:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Вниз:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Влево:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Вправо:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Активировать флаг:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Темы</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Выберите файл темы</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Невозможно создать папку для данных.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Невозможно скопировать файл темы.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Подтверждение</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Удалить выбранную тему?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Невозможно удалить выбранную тему.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Об игре</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новая</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Подсказка</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Очки</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>У&amp;величить</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Ум&amp;еньшить</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Язык приложения</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Предпочтения</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Об игре</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Игра в лабиринт с видом сверху</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Копирайт &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Выпущено под лицензией &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Иконки из темы &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Используются под лицензией &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> cutemaze_1.3.2.orig.tar.gz: cutemaze-1.3.2/translations/cutemaze_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Невозможно загрузить предыдущую игру. Будет создана новая игра.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 прошло</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 шагов сделано</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 из %2 целей осталось</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Успех</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Пауза</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Опция</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Выберите язык приложения:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Системный язык&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Пожалуйста, перезапустите программу для того, чтобы изменения вступили в силу.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Новая игра</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Охота и убийство</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Краскал</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Прим</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Рекурсивный обход</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Стек</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Стек 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Стек 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Стек 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Стек 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Алгоритм:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Целей:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Размер:</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Очки</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Шагов</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Алгоритм</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Поздравляем!</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Игра</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Показывать, где вы уже были</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Показывать количество шагов</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Показывать прошедшее время</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Гладкое движение</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Управление</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Вверх:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Вниз:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Влево:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Вправо:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Активировать флаг:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Темы</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Выберите файл темы</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Невозможно создать папку для данных.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Невозможно скопировать файл темы.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Подтверждение</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Удалить выбранную тему?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Невозможно удалить выбранную тему.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Об игре</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новая</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Подсказка</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Очки</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>У&amp;величить</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Ум&amp;еньшить</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Язык приложения</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Предпочтения</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Об игре</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Игра в лабиринт с видом сверху</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Копирайт &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Выпущено под лицензией &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Иконки из темы &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Используются под лицензией &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
